@@ -17,7 +17,6 @@ import os
 from oslo_concurrency import lockutils
 from oslo_log import log as logging
 from oslo_service import loopingcall
-import six
 
 from os_brick import exception
 from os_brick.i18n import _
@@ -80,7 +79,7 @@ class FibreChannelConnector(base.BaseLinuxConnector):
             wwns = target_wwns
         elif isinstance(target_wwn, list):
             wwns = target_wwn
-        elif isinstance(target_wwn, six.string_types):
+        elif isinstance(target_wwn, str):
             wwns = [target_wwn]
         else:
             wwns = []
@@ -169,7 +168,7 @@ class FibreChannelConnector(base.BaseLinuxConnector):
         return volume_paths
 
     @utils.trace
-    @synchronized('extend_volume', external=True)
+    @synchronized('extend_volume')
     def extend_volume(self, connection_properties):
         """Update the local kernel's size information.
 
@@ -190,7 +189,7 @@ class FibreChannelConnector(base.BaseLinuxConnector):
             raise exception.VolumePathsNotFound()
 
     @utils.trace
-    @synchronized('connect_volume', external=True)
+    @synchronized('connect_volume')
     def connect_volume(self, connection_properties):
         """Attach the volume to instance_name.
 
@@ -315,7 +314,7 @@ class FibreChannelConnector(base.BaseLinuxConnector):
         return raw_devices
 
     @utils.trace
-    @synchronized('connect_volume', external=True)
+    @synchronized('connect_volume')
     def disconnect_volume(self, connection_properties, device_info,
                           force=False, ignore_errors=False):
         """Detach the volume from instance_name.
